#!/usr/bin/env bash

setup() {
  load "$PWD/tests/integration/helpers/common"
  _common_setup
}

@test "recipe lint" {
  run $ABRA recipe lint gitea
  assert_success
  assert_output --partial 'compose config has expected version'
}

@test "recipe lint warns on error" {
  run $ABRA recipe lint "$TEST_RECIPE"
  assert_success
  refute_output --partial 'watch out, some critical errors are present'

  run sed -i '/traefik.enable=.*/d' "$ABRA_DIR/recipes/$TEST_RECIPE/compose.yml"
  assert_success

  run $ABRA recipe lint "$TEST_RECIPE"
  assert_success --partial 'watch out, some critical errors are present'

  _checkout_recipe "$TEST_RECIPE"
}

@test "recipe lint uses latest commit" {
  _fetch_recipe "$TEST_RECIPE"

  latestCommit="$(git -C "$ABRA_DIR/recipes/$TEST_RECIPE" rev-parse --short HEAD)"

  run git -C "$ABRA_DIR/recipes/$TEST_RECIPE" reset --hard HEAD~3
  assert_success

  run git -C "$ABRA_DIR/recipes/$TEST_RECIPE" status
  assert_output --partial 'behind 3'

  run $ABRA recipe lint "$TEST_RECIPE"
  assert_success

  run git -C "$ABRA_DIR/recipes/$TEST_RECIPE" status
  assert_output --partial 'behind 3'

  run git -C "$ABRA_DIR/recipes/$TEST_RECIPE" checkout "$latestCommit"
  assert_success

  run git -C "$ABRA_DIR/recipes/$TEST_RECIPE" status
  refute_output --partial 'behind 3'
}
